#!/bin/ksh
#-------------------------------------------------------------------------------------------------------------------
# Script que realiza un envio FTP 
#
# Valores de salida:    0 - Proceso finalizado OK.
#                     300 - Error: Error de conexion via FTP.
#                     301 - Error: Error al loguearse a maquina remota.
#                     302 - Error: Error en la transferencia de ficheros.
#		      303 - Error: Error en la compresion del fichero.
#		      304 - Error: Error al borrar los archivos
#-------------------------------------------------------------------------------------------------------------------


VARENTORNO='.varentorno'
. $VARENTORNO

TRANSFER_COMPLETE='Transfer complete.'

echo "<`date`> | Comenzando envio FTP." > $AP_PATH_LOGS"/"$AP_LOG_FTP

dia=`date +%d`
mes=`date +%m`
anio=`date +20%y`
fecha=$anio"_"$mes"_"$dia

gzip -v9 -f $AP_PATH"/"$AP_NAME_FILE$fecha.txt > /dev/null 2>&1

if [ $? != 0 ]
then
	echo "<`date`> | Error en la compresion del fichero." >> $AP_PATH_LOGS"/"$AP_LOG_FTP
	exit 303
fi

# Realizo el FTP de los ficheros de datos
ftp -dinv $ip_remote << EOF! >> $AP_PATH_LOGS"/"$AP_LOG_FTP
user $user $pass
cd   $AP_PATH_DESTINO
lcd  $AP_PATH
mput *.gz
bye
EOF!

rptaftp=` grep -c 'ready' $AP_PATH_LOGS"/"$AP_LOG_FTP`
login=` grep -c 'logged in' $AP_PATH_LOGS"/"$AP_LOG_FTP`
 
CANTIDAD_FICH_DAT=`ls $AP_PATH/*.gz 2>/dev/null | wc -l | tr -d ' '`
#echo "Cantidad de ficheros: $CANTIDAD_FICH_DAT "

TRANSFER_FTP_DESC=` grep -c "$TRANSFER_COMPLETE" $AP_PATH_LOGS"/"$AP_LOG_FTP`

#echo "$TRANSFER_FTP_DESC"

if [ $rptaftp -eq 1 ]
then
	echo "<`date`> | Conexion via FTP exitosa." >> $AP_PATH_LOGS"/"$AP_LOG_FTP

else
	echo "<`date`> | Conexion via FTP sin exito. <EXIT=15>" >> $AP_PATH_LOGS"/"$AP_LOG_FTP
	exit 300
fi

if [ $login -eq 1 ]
then
	echo "<`date`> | Logeo exitoso." >> $AP_PATH_LOGS"/"$AP_LOG_FTP

else
	echo "<`date`> | Logeo incorrecto. <EXIT=16>" >> $AP_PATH_LOGS"/"$AP_LOG_FTP
	exit 301
fi

if [ $TRANSFER_FTP_DESC -eq $CANTIDAD_FICH_DAT ] 
then
    echo "<`date`> | Transferencia de ficheros via FTP completada." >> $AP_PATH_LOGS"/"$AP_LOG_FTP
else
    echo "<`date`> | Error en la transferencia de ficheros via FTP.<EXIT=17>" >> $AP_PATH_LOGS"/"$AP_LOG_FTP
    exit 302
fi

echo "<`date`> | Proceso de FTP finalizado OK." >> $AP_PATH_LOGS"/"$AP_LOG_FTP

#Una vez que se ha enviado correctamente el fichero, se elimina
rm $AP_PATH"/"$AP_NAME_FILE*.txt.gz 
if [ $? != 0 ]
then
	echo "<`date`> | Error al borrar los archivos $AP_PATH\"/\"$AP_NAME_FILE" >> $AP_PATH_LOGS"/"$AP_LOG_FTP 
	exit 304
fi

echo "<`date`> | Borrados archivos $AP_PATH/$AP_NAME_FILE*.txt.gz" >> $AP_PATH_LOGS"/"$AP_LOG_FTP

exit 0

